#!/bin/bash

dir="${dir=:-$(pwd)}"
# Functions used in perf_metrics.sh

#Checks if the job submission ended correctly. 
Job_completed()
{
  if [ "$Jobs_scheduler" == "slurm" ]; then
    local id1
    id1=${1##* }
    until ! scontrol show job "$id1" | grep -q 'JobState=COMPLETING' 
    do
      sleep 1
    done
    if ! scontrol show job "$id1" | grep -q 'JobState=COMPLETED'; then
      Completed=false
    else
      Completed=true
    fi	

  elif [ "$Jobs_scheduler" == "lsf" ]; then
    local id2
    id2=$(head -n1 "$1" | cut -d'<' -f2 | cut -d'>' -f1)
    if ! bjobs -l "$id2" | grep -q 'Status <DONE>'; then
      Completed=false
    else
      Completed=true
    fi
  elif [ "$Jobs_scheduler" == "torque" ]; then
    local id3
    id3=$(head -n1 "$1" | awk '{ print $3 }')
    if ! qstat f "$id3" | grep -q 'exit_status = 0'; then
      Completed=false
    else
      Completed=true
    fi
  fi
  

}

# Check if nemo is compiled for using extrae

Compile_extrae()
{
  trap "trap - SIGTERM && kill -- -$$" SIGINT SIGTERM EXIT
  #Get flag lines

  line=$(sed -n '/^%FCFLAGS /p' "$Nemo_path"/arch/arch-"${arch}".fcm)
  line2=$(sed -n '/^%FPPFLAGS /p' "$Nemo_path"/arch/arch-"${arch}".fcm)
  line3=$(sed -n '/^%LDFLAGS /p' "$Nemo_path"/arch/arch-"${arch}".fcm)


  # If -rdynamic is not there recompilation is requiered and -rdynamic added

  if ! echo "${line}"|grep -q "\-rdynamic\b"; then
    echo "-rdynamic flag not found in FCFLAGS arch-${arch}.fcm: editing arch-${arch}.fcm "
    sed -i '/^%FCFLAGS/ s/$/ -rdynamic/' "${Nemo_path}"/arch/arch-"${arch}".fcm
    compile_ext=true
  fi

  if ! echo "${line3}"|grep -q "\-export-dynamic\b"; then
    echo "-export-dynamic flag not found in LDFLAGS arch-${arch}.fcm: editing arch-${arch}.fcm "
    sed -i '/^%LDFLAGS/ s/$/ -export-dynamic/' "${Nemo_path}"/arch/arch-"${arch}".fcm
    compile_ext=true
  fi
  
   # If finstrument-functions is not there recompilation is requiered and -finstrument-functions added
  if ! echo "${line}"|grep -q "\-finstrument-functions\b"; then
    echo "-finstrument-functions flag not found in arch-${arch}.fcm: editing arch-${arch}.fcm "
    sed -i '/^%FCFLAGS/ s/$/ -finstrument-functions/' "${Nemo_path}"/arch/arch-"${arch}".fcm
    compile_ext=true
  fi

  # If -g is not there, recompilation is requiered and -g added
    if ! echo "${line}"|grep -q "\-g\b"; then
      echo "-g flag not found in arch-${arch}.fcm: editing arch-${arch}.fcm "
      sed -i '/^%FCFLAGS/ s/$/ -g /' "${Nemo_path}"/arch/arch-"${arch}".fcm
      compile_ext=true
    fi

  
  if [ "$compile" == true ]; then
      echo 'compile parameter is inicialized true'
  fi

  # If -pg is  there recompilation is requiered and -pg removed 

  sed -i 's/-pg//g' "${Nemo_path}"/arch/arch-"${arch}".fcm

  if echo "${line}"|grep -q "\-pg\b"; then
    echo "-pg flag found in FCFLAGS arch-${arch}.fcm: editing arch-${arch}.fcm "
    compile_ext=true
  fi

  if echo "${line2}"|grep -q "\-pg\b"; then
    echo "-pg flag found in FPPFLAGS arch-${arch}.fcm : editing arch-${arch}.fcm "
    compile_ext=true
  fi

  if echo "${line3}"|grep -q "\-pg\b"; then
    echo "-pg flag found in LDFLAGS arch-${arch}.fcm: editing arch-${arch}.fcm "
    compile_ext=true
  fi
   
  # If nemo executable is not on the run file compile

  if ! test -f "${Nemo_path}/cfgs/${name_cfg}/EXP00/nemo"; then
    echo "nemo executable not found in ${name_cfg}"
    compile_ext=true
  fi


  if [ "$compile" == true ] || [ "$compile_ext" == true ]; then

    echo "Compiling Nemo for EXTRAE"
   

   
    python3 "$dir"/src/./Job_Creator.py -f "compile_extrae" -j "compile_extrae" --set-core "${Jobs_n_cores}" \
    --set-core-per-node "$Jobs_cores_per_node" -s "$Jobs_scheduler" --set-time "$time" --set-queue "$queue" \
    -w "cd ${Nemo_path}; ./makenemo -r ${cfg} -n ${name_cfg} -m ${arch} -j$Jobs_n_cores $comp_cfg || exit 1; cd ${Run_path}"
    cp compile_extrae.* "${logs_path}"
    
    if ! state1=$("$job" "$wait" compile_extrae."$Jobs_scheduler"); then
      echo "Nemo compilation failed, remember to load all the needed modules. Check the details in ${logs_path}/compile_extrae.err"
      exit 1
    fi
    
    echo
    Job_completed "$state1"
    if [ $Completed == false ]; then
      echo "Nemo compilation failed, remember to load all the needed modules. Check the details in ${logs_path}/compile_extrae.err"
      echo
      exit 1
    else 
      echo "Nemo Extrae compilation successful"
      echo
     
    fi
    

  else
    echo "Compilation not needed"  
    echo
  fi

 

}

#Check if Nemo is compiled for using Gprof

Compile_gprof()
{
  trap "trap - SIGTERM && kill -- -$$" SIGINT SIGTERM EXIT
  if [ "$compile" == true ]; then
    echo 'compile parameter is inicialized true'
  fi

  # Checking if Gprof_arch file is present
  if ! test -f "${Nemo_path}/arch/arch-${arch}_GPROF.fcm"; then
    cp "${Nemo_path}"/arch/arch-"${arch}".fcm "${Nemo_path}"/arch/arch-"${arch}"_GPROF.fcm
  fi

  # Get text lines corresponding to the flags
  line=$(sed -n '/^%FCFLAGS /p' "$Nemo_path"/arch/arch-"${arch}"_GPROF.fcm)
  line2=$(sed -n '/^%FPPFLAGS /p' "$Nemo_path"/arch/arch-"${arch}"_GPROF.fcm)
  line3=$(sed -n '/^%LDFLAGS /p' "$Nemo_path"/arch/arch-"${arch}"_GPROF.fcm)
  
  # If -g is not there, recompilation is requiered and -g added
  if ! echo "${line}"|grep -q "\-g\b"; then
    echo "-g flag not found in arch-${arch}_GPROF.fcm: editing arch-${arch}_GPROF.fcm "
    sed -i '/^%FCFLAGS/ s/$/ -g /' "${Nemo_path}"/arch/arch-"${arch}"_GPROF.fcm
    comp_gprof=true
  fi

  # If -pg is not there recompilation is requiered and -pg added

  if ! echo "${line}"|grep -q "\-pg\b"; then
    echo "-pg flag not found in FCFLAGS arch-${arch}_GPROF.fcm: editing arch-${arch}_GPROF.fcm "
    sed -i '/^%FCFLAGS/ s/$/ -pg/' "${Nemo_path}"/arch/arch-"${arch}"_GPROF.fcm
    comp_gprof=true
  fi

  if ! echo "${line2}"|grep -q "\-pg\b"; then
    echo "-pg flag not found in FPPFLAGS arch-${arch}_GPROF.fcm : editing arch-${arch}_GPROF.fcm "
    sed -i '/^%FPPFLAGS/ s/$/ -pg/' "${Nemo_path}"/arch/arch-"${arch}"_GPROF.fcm
    comp_gprof=true
  fi

  if ! echo "${line3}"|grep -q "\-pg\b"; then
    echo "-pg flag not found in LDFLAGS arch-${arch}_GPROF.fcm: editing arch-${arch}_GPROF.fcm "
    sed -i '/^%LDFLAGS/ s/$/ -pg/' "${Nemo_path}"/arch/arch-"${arch}"_GPROF.fcm
    comp_gprof=true
  fi

  # If nemo executable is not on the run file compile

  if ! test -f "${Nemo_path}/cfgs/${name_cfg}_GPROF/EXP00/nemo"; then
    echo "nemo executable not found in ${name_cfg}_GPROF"
    comp_gprof=true
  fi

  if [ "$compile" == true ] || [ "$comp_gprof" == true ]; then
    echo "Compiling Nemo for GPROF"
    python3 "$dir"/src/./Job_Creator.py -f "compile_gprof" -j "compile_gprof" --set-core "${Jobs_n_cores}" \
    --set-core-per-node "$Jobs_cores_per_node" -s "$Jobs_scheduler" --set-time "$time" --set-queue "$queue" \
    -w "cd ${Nemo_path}; ./makenemo -r ${cfg} -n ${name_cfg}_GPROF -m ${arch}_GPROF -j$Jobs_n_cores $comp_cfg || exit 1; cd ${Gprof_path};"
    
    cp compile_gprof.* "${logs_path}"  
    if ! state1=$("$job" "$wait" compile_gprof."$Jobs_scheduler"); then
      echo "Nemo compilation failed, remember to load all the needed modules. Check the details in ${logs_path}/compile_gprof.err"
      exit 1
    fi
    
    echo
    Job_completed "$state1"
    if [ "$Completed" == false ]; then
      echo "Nemo compilation failed, remember to load all the needed modules. Check the details in ${logs_path}/compile_gprof.err"
      echo
      exit 1
    else 
      echo "Nemo Gprof compilation successful"
      echo
      
    fi
    

  else
    echo "Compilation not needed"  
    echo
  fi

  #Copy all the EXP00 data in Gprof folder but don't overwrite the namelist, just the executable.
 
  cp  "${Nemo_path}"/cfgs/"${name_cfg}"_GPROF/EXP00/* "${Gprof_path}"
  cp  "${Nemo_path}"/cfgs/"${name_cfg}"_GPROF/EXP00/nemo "${Gprof_path}"
  

  if [[ $comp_cfg == "-d OCE del_key 'key_si3 key_top'" ]]; then
    sed -i '/_def_nemo-ice.xml\|def_nemo-pisces.xml/d' "${Gprof_path}"/context_nemo.xml #DELETE ICE AND PISCES CONTEXT (NOT USED)
  fi
  
  if [ $Nemo_output == false ]; then
    sed -i '/<file_definition/d' "${Gprof_path}"/context_nemo.xml #DELETING OUTPUT DEFINITON
  fi
}


#Init variables with default values in case of missing

Init()
{
  Output="${Output=:-"../"}"
  Nemo_path="${Nemo_path:-"./"}"
  Nemo_input_data="${Nemo_input_data=:-"./"}"
  Nemo_cores="${Nemo_cores:-( 48 )}"
  Nemo_output="${Nemo_output:-false}"
  Jobs_n_cores="${Jobs_n_cores:-48}"
  Jobs_cores_per_node="${Jobs_cores_per_node:-0}"
  Jobs_scheduler="${Jobs_scheduler:-"slurm"}"
  time="${Jobs_time:-0}"
  queue="${Jobs_queue:-""}"
  compile="${Compilation_compile:-false}"
  cfg="${Compilation_ref:-"ORCA2_ICE_PISCES"}"
  arch="${Compilation_arch:-"X64_MN4"}"
  name_cfg="${Compilation_name:-"ORCA2_EXTRAE"}"
  comp_cfg="${Compilation_sub:-""}"
  Clean="${Clean:-true}"
  Modules="${Modules:-""}"
  Nemo_iterations=12
  compile_ext=false
  comp_gprof=false
}


# Checks if the paths given are correct.

Test_arguments()
{


  # Does Output path exist?
  if ! test -d "${Output}"; then
    echo "Output path: ${Output} is not found,  modify it in perf_metrics.config with the correct path"
    echo
    exit 1
  # Transform to absolute path
  else 
    cd "${Output}" || (echo "$Output dir doesn't exist"; exit 1)
    Output=$(pwd)
    cd "$dir" || (echo "$dir dir doesn't exist"; exit 1)
  fi

  # Nemo path correct?
  if ! test -d "${Nemo_path}"; then
    echo "Nemo relative path: ${Nemo_path} is not found, modify it in perf_metrics.config with the correct path"
    echo
    exit 1
  # Transform to absolute path
  else
    cd "${Nemo_path}" || (echo "${Nemo_path} dir doesn't exist"; exit 1)
    Nemo_path=$(pwd)
    cd "$dir" || (echo "$dir dir doesn't exist"; exit 1)
  fi
   # Is Nemo data path correct?
  if ! test -d "${Nemo_input_data}"; then
    echo "Nemo input data path: ${Nemo_input_data} is not found,  modify it in perf_metrics.config with the correct path"
    echo
    exit 1
  # Transform to absolute path
   else 
    cd "${Nemo_input_data}" || (echo "${Nemo_input_data} dir doesn't exist"; exit 1)
    Nemo_input_data=$(pwd)
    cd "$dir" || (echo "$dir dir doesn't exist"; exit 1)
  fi
   
  #Nemo_cores is array?
  if [[ ! "$(declare -p Nemo_cores)" =~ "declare -a" ]]; then
    echo "Error Nemo_cores has to be a bash array like ( 4 24 48 ), modify it in perf_metrics.config with a valid value"
    echo
    exit 1
  fi
  
  #Nemo_cores contains ints?
  
  re='^[0-9]+$'
  for core in "${Nemo_cores[@]}"
  do

    if ! [[ $core =~ $re ]] ; then
      echo "Error Nemo_cores has to contain integer values,  modify it in perf_metrics.config with a valid value"
      echo
      exit 1
    fi
  done

  # cfg exists?
  if ! test -d "${Nemo_path}/cfgs/${cfg}"; then
    echo "configuration: ${cfg} doesn't exists in ${Nemo_path}/cfgs dir, modify it in perf_metrics.config with a valid cfg"
    echo
    exit 1
  fi
  # arch exists?
  if ! test -f "${Nemo_path}/arch/arch-${arch}.fcm"; then
    echo "architecture: arch-${arch}.fcm doesn't exists in ${Nemo_path}/arch dir, modify it in perf_metrics.config with a valid arch"
    echo
    exit 1
  fi
  # scheduler correct?
  if [ "$Jobs_scheduler" != "slurm" ] && [ "$Jobs_scheduler" != "lsf" ] && [ "$Jobs_scheduler" != "torque" ]; then
    echo "$Jobs_scheduler is not a valid scheduler, modify it in perf_metrics.config with a valid scheduler (slurm/lsf/torque)"
    echo
    exit 1
  fi
  #Nemo_cores is array?
  if [[ ! "$(declare -p Nemo_cores)" =~ "declare -a" ]]; then
    echo "Error, variable Nemo_cores has to be an array, modify it in perf_metrics.config with a proper value"
    echo
    exit 1
  fi
  #Modules available
  if ! module load $Modules;then
    echo "Error loading modules aborting, modify the modules loaded in perf_metrics.config"
    echo
    exit 1
  fi
  echo
  #$EXTRAE_HOME loaded ?
  if ! test -d "${EXTRAE_HOME}"; then
  echo "Extrae relative path: ${EXTRAE_HOME} is not found"
    echo
    exit 1
  else
    sed -i 's|home=.*|home="'"$EXTRAE_HOME"'"|g' src/extrae.xml
  fi
  
  # Adding -d to variable if not empty
  if [ -n "$comp_cfg" ]; then
    comp_cfg="-d $comp_cfg"
  fi
  
  # Creating auxiliar vars for submiting jobs
  if [ "$Jobs_scheduler" == "slurm" ]; then 
    job="sbatch"
    wait="--wait"
  elif [ "$Jobs_scheduler" == "lsf" ]; then
    job="bsub"
    wait="-K"
  elif [ "$Jobs_scheduler" == "torque" ]; then
    job="qsub"
    wait="-sync"
  fi

  # Changing trace.sh reference to extrae.xml

  sed -i "s|export EXTRAE_CONFIG_FILE=.*|export EXTRAE_CONFIG_FILE=$dir/src/./extrae.xml|g" src/trace.sh
  
  #Creating output folder after comprovations

  Output_dir="${Output}/Output"
  mkdir -p "${Output_dir}"
  
  # Creating logs folder

  logs_path="${Output_dir}/logs"
  mkdir -p "$logs_path" 
  rm -f "$logs_path"/*
   
  # Creating gprof folder

  Gprof_path="${Output_dir}/gprof"
  mkdir -p "$Gprof_path" 
  cp -s -f "${Nemo_input_data}"/* "${Gprof_path}"

  # Create Run_Nemo folder

  Run_path="${Output_dir}/Run_NEMO"
  mkdir -p "${Run_path}"

  # Creating Metricsfolder

  Metrics_path="${Output_dir}/Metrics"
  mkdir -p "${Metrics_path}"
  
}




# Generates a list of Nemo functions 

Gprof_functions()
{
  trap "trap - SIGTERM && kill -- -$$" SIGINT SIGTERM EXIT
  #Generating function list in case of missing
  if ! test -f "extrae_functions_${name_cfg}.txt"; then

    Compile_gprof
    #Changing iterations, big traces generate problems.
    sed -i "s|nn_itend * =.*|nn_itend    =       $Nemo_iterations  !  last  time step (std 5475)|g" namelist_cfg
    rm gmon* 2> /dev/null
    echo "Runing Nemo with 2 cores to obtain function data..."
    echo
    python3 "$dir"/src/./Job_Creator.py -f "run" -j "run" --set-core 4 --set-core-per-node "$Jobs_cores_per_node" \
    -s "$Jobs_scheduler" --set-time "$time" --set-queue "$queue" -w "mpirun -np 2 ./nemo || exit 1" 
    
    cp run.* "${logs_path}" 
    if ! state2=$("$job" "$wait"  run."$Jobs_scheduler"); then 
      echo "Nemo execution failed look at ${logs_path}/run.err and ${Gprof_path}/ocean.output for more info"
      echo "Remember that the namelist files copied are the default ones, change them inside "${Nemo_path}"/cfgs/"${name_cfg}"_GPROF/EXP00/ in order to fit with the input files provided " 
      exit 1
    fi
    Job_completed "$state2"
    if [ $Completed == false ]; then
      echo "Nemo execution failed look at ${logs_path}/run.err and ${Gprof_path}/ocean.output for more info"
      echo "Remember that the namelist files copied are the default ones, change them inside "${Nemo_path}"/cfgs/"${name_cfg}"_GPROF/EXP00/ in order to fit with the input files provided " 
      echo
      exit 1
    else 
      echo "Gprof files generated "
      echo
    fi
  

    echo "Gthrottling functions ..."
    echo
    python3 "$dir"/src/./Job_Creator.py -f "gthrottling" -j "gthrottling" --set-core 4 \
    --set-core-per-node "$Jobs_cores_per_node" -s "$Jobs_scheduler" \
    --set-time "$time" --set-queue "$queue" -w "$dir/src/./gthrottling.sh nemo" 
    
    cp gthrottling.* "${logs_path}"
    if ! state3=$("$job" "$wait" gthrottling."$Jobs_scheduler"); then
      echo "Error listing functions, look at ${logs_path}/gthrottling.err for more info"
      exit 1
    fi
    Job_completed "$state3"
    if [ $Completed == false ]; then
      echo "Job not completed, the job scheduler is cancelling it or something make it fail"
      echo
      exit 1
    else
      mv extrae_functions.txt extrae_functions_"${name_cfg}".txt
      echo "Functions listed correctly"
      echo
      
    fi
      
  else
    echo "Functions already listed, file ${Gprof_path}/extrae_functions_${name_cfg}.txt does exist."
    echo
    
  fi
}


#Gets a trace from Nemo and cuts it to obtain a single timestep

Get_trace()
{
  Compile_extrae
  trap "trap - SIGTERM && kill -- -$$" SIGINT SIGTERM EXIT
  wait

  "$dir"/src/./extraf.sh  "${Nemo_path}"/cfgs/"${name_cfg}"/EXP00/nemo "${Gprof_path}"/extrae_functions_"${name_cfg}".txt > /dev/null
  sed -i "s|list=.*|list=\"${Run_path}/extrae_functions_for_xml.txt\" exclude-automatic-functions=\"yes\">|g" "$dir"/src/extrae.xml

  for core in "${Nemo_cores[@]}" 
  
  do
    (
    

    # Create folder for n cores
    mkdir -p "$core"_cores
    cd "$core"_cores || (echo "$core dir doesn't exist"; exit 1)
    
    # Copy all the EXP00 data but don't overwrite namelist just the executable
  
    cp  "${Nemo_path}"/cfgs/"${name_cfg}"/EXP00/* .
    cp  "${Nemo_path}"/cfgs/"${name_cfg}"/EXP00/nemo .
    cp -s -f "${Nemo_input_data}"/* .
    
    # Change iterations
    sed -i "s|nn_itend * =.*|nn_itend    =       $Nemo_iterations  !  last  time step (std 5475)|g" namelist_cfg
    if [[ $comp_cfg == "-d OCE del_key 'key_si3 key_top'" ]]; then
      sed -i '/_def_nemo-ice.xml\|def_nemo-pisces.xml/d' context_nemo.xml #DELETE ICE AND PISCES CONTEXT (NOT USED)
    fi

    if [ $Nemo_output == false ]; then
      sed -i '/<file_definition/d' context_nemo.xml #DELETING OUTPUT DEFINITON
    fi

    # Obtain trace
    echo "Creating trace with $core cores..."
    echo
    python3 "$dir"/src/./Job_Creator.py -f "run_extrae_$core" -j "run_extrae_$core" --set-core "$core" \
    --set-core-per-node "$Jobs_cores_per_node" -s "$Jobs_scheduler" --set-time "$time" \
    --set-queue "$queue" -w "mpirun -np $core $dir/src/./trace.sh ./nemo || exit 1" 
    
    if ! state4=$("$job" "$wait" run_extrae_"$core"."$Jobs_scheduler") ; then
      echo "Nemo execution failed, no traces files generated more info inside ${logs_path}/run_extrae_$core.err"
      echo "Remember that the namelist files copied are the default ones, change them inside "${Nemo_path}"/cfgs/"${name_cfg}"_GPROF/EXP00/ in order to fit with the input files provided "
      kill 0
      exit 1
    fi
    Job_completed "$state4"
    mv run_extrae_"$core".* "${logs_path}"

    if [ $Completed == false ]; then
      echo "Nemo execution failed, no traces files generated more info inside ${logs_path}/run_extrae_$core.err"
      echo "Remember that the namelist files copied are the default ones, change them inside "${Nemo_path}"/cfgs/"${name_cfg}"_GPROF/EXP00/ in order to fit with the input files provided "
      kill 0
      exit 1
    fi
    mv nemo.prv nemo_"$core".prv
    mv nemo.pcf nemo_"$core".pcf
    mv nemo.row nemo_"$core".row	
    echo "Cutting up best iteration"
    "$dir"/src/magiccut/./magicCut nemo_"${core}".prv "$Nemo_iterations" > "${logs_path}"/cut_"$core".out 2>&1

    if ! ls nemo_"$core".best_cut.prv; then
      echo "Cut failed, look at ${logs_path}/cut_$core.out for more info." 
      kill 0
      exit 1
    fi
    echo
    cp nemo_"$core".best_cut.* "${Metrics_path}"
    cd "$Run_path" || (echo "$Run_path dir doesn't exist"; exit 1)
    )&
      
  done

  wait
}

Create_metrics()
{
  
  # Create performance metrics
  echo "Creating metrics and storing them in ${Metrics_path} folder"
  echo
  python3 "$dir"/src/./Job_Creator.py -f "analysis" -j "analysis" \
  --set-core "${Jobs_n_cores}" --set-core-per-node "$Jobs_cores_per_node" -s "$Jobs_scheduler" \
  --set-time "$time" --set-queue "$queue" -w "$dir/src/./modelfactors.py -ms 100000 *" 
  

  cp analysis.* "${logs_path}"
  if ! state5=$("$job" "$wait" analysis."$Jobs_scheduler"); then
    echo "Error, metrics have not generated check ${logs_path}/analysis.err to get more details" 
    exit 1
  fi
  
  Job_completed "$state5"
  cp analysis.out overview.txt
  rm analysis.* 
  if [ $Completed == false ]; then
    echo "Error, metrics have not generated check ${logs_path}/analysis.err to get more details"
    echo
    exit 1
 
  fi
 
  # Removing run folders
  if [ "$Clean" == true ]; then
    rm -r -f "$Run_path"
    mv "${Gprof_path}"/extrae_functions* "$dir"
    rm -r -f "${Gprof_path:?}"/*
    mv "${dir}"/extrae_functions* "${Gprof_path}"
  fi

  echo "------------------------------------------------------------------------------"
  echo "------------------------- Script Completed -----------------------------------"
  echo "--- Data in ${Metrics_path} folder ---"
  echo "------------------------------------------------------------------------------"
  echo "------------------------------------------------------------------------------"
  echo
}
